credentials

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2022 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// IDRegexp matches a valid Credentials ID
	IDRegexp = regexp.MustCompile(`^[_a-zA-Z0-9][-_a-zA-Z0-9]{0,127}$`)
)

Functions

This section is empty.

Types

type AWSSTSCredentials added in v0.2.0

type AWSSTSCredentials struct {
	ID              string
	Name            string
	Description     string
	RoleARN         string
	RoleSessionName string
	MaxMinutes      uint
	Tags            map[string]string
	Version         uint
}

AWSSTSCredentials represents a set of AWS STS credentials

type Client

type Client interface {
	ConvertNameToID(name string) string
	ConvertTags(tags map[string]string) []*credentials.Tag
	IsNotFoundError(err error) bool
	IsUnprocessableEntityError(err error) bool
	IsRetryableError(err error) bool

	CreateAWSSTS(ctx context.Context, p *credentials.CreateAwsStsPayload) (string, error)
	ShowAWSSTS(ctx context.Context, id string) (*AWSSTSCredentials, error)
	UpdateAWSSTS(ctx context.Context, p *credentials.UpdateAwsStsPayload) error
	DeleteAWSSTS(ctx context.Context, id string) error

	CreateOAuth2(ctx context.Context, p *credentials.CreateOauth2Payload) (string, error)
	UpdateOAuth2(ctx context.Context, p *credentials.UpdateOauth2Payload) error
}

Client is thin wrapper around the generated front service clients in the SDK

func NewClient

func NewClient(host string, projectID uint64, ts auth.TokenSource, debug bool) Client

NewClient returns a new client for the Flexera Credentials service

Jump to